<?php
/**
 * WordPress.com-specific functions and definitions
 * This file is centrally included from `wp-content/mu-plugins/wpcom-theme-compat.php`.
 *
 * @package Fontfolio
 */

function fontfolio_theme_colors() {
	global $themecolors;

	/**
	 * Set a default theme color array for WP.com.
	 *
	 * @global array $themecolors
	 */
	if ( ! isset( $themecolors ) ) :
		$themecolors = array(
			'bg' => 'ffffff',
			'border' => 'cccccc',
			'text' => '666666',
			'link' => '000000',
			'url' => '000000',
		);
	endif;
}
add_action( 'after_setup_theme', 'fontfolio_theme_colors' );

/*
 * De-queue Google fonts if custom fonts are being used instead
 */

function fontfolio_dequeue_fonts() {
	if ( class_exists( 'TypekitData' ) ) {
		if ( TypekitData::get( 'upgraded' ) ) {
			$customfonts = TypekitData::get( 'families' );
				if ( ! $customfonts )
					return;

				$site_title = $customfonts['site-title'];
				$headings = $customfonts['headings'];
				$body_text = $customfonts['body-text'];

				if ( $site_title['id'] && $headings['id'] && $body_text['id'] ) {
					wp_dequeue_style( 'fontfolio-droid-sans' );
			}
		}
	}
}

add_action( 'wp_enqueue_scripts', 'fontfolio_dequeue_fonts' );



/*
 * WordPress.com Print Styles
 */
function fontfolio_print_styles() {

	add_theme_support( 'print-style' );

}
add_action( 'after_setup_theme', 'fontfolio_print_styles' );

//WordPress.com specific styles
function fontfolio_wpcom_styles() {
	wp_enqueue_style( 'fontfolio-wpcom', get_template_directory_uri() . '/inc/style-wpcom.css', '080213' );
}
add_action( 'wp_enqueue_scripts', 'fontfolio_wpcom_styles' );